@@ -1,15 +1,17 @@
 import itertools
+import requests
+
+from time import sleep
+from dataclasses import asdict
+from pathlib import Path
+
 from retry import retry
 from retry.api import retry_call
-from dataclasses import asdict
-import requests
-from packaging.version import parse as parse_version
-from time import sleep
-
 from uiautomator2.core import HTTPResponse, _http_request
-from kea2.adbUtils import ADBDevice, ADBStreamShell_V2
-from pathlib import Path
-from kea2.utils import getLogger, getProjectRoot
+from packaging.version import parse as parse_version
+
+from .utils import getLogger, getProjectRoot
+from .adbUtils import ADBDevice, ADBStreamShell_V2
 
 
 from typing import IO, TYPE_CHECKING, Dict
@@ -117,6 +119,7 @@ class FastbotManager:
         post_data = {
             "takeScreenshots": options.take_screenshots,
             "preFailureScreenshots": options.pre_failure_screenshots,
+            "postFailureScreenshots": options.post_failure_screenshots,
             "logStamp": stamp,
             "deviceOutputRoot": options.device_output_root,
         }
